@@ -19,6 +19,7 @@ def command_config(log: Logger, path: Path, ns: object):
         print(f"organization: {bold(repo.organization or '')}")
         print(f"user:         {bold(repo.user or '')}")
         print(f"snapshot:     {bold(repo.snapshot or '')}")
+        print(f"scenario:     {bold(repo.scenario or '')}")
     else:
         print(cyan(f"Set configuration for {bold(name)}"))
         if ns.remote:
@@ -33,5 +34,8 @@ def command_config(log: Logger, path: Path, ns: object):
         if ns.snapshot:
             print(f"snapshot     = {bold(ns.snapshot)}")
             repo.snapshot = ns.snapshot
+        if ns.scenario:
+            print(f"scenario     = {bold(ns.scenario)}")
+            repo.scenario = ns.scenario
         if input(yellow("Save changes? (y/n) ")).strip().lower() == "y":
             repo.save()
